@@ -38,7 +38,4 @@ class Article(models.Model):
 
     def __unicode__(self):
         return u'%s' % self.title
-
-    def get_absolute_url(self):
-        return "%s" % (self.get_absolute_url())
     
